# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/evaluatr',
                'doc_host': 'https://franckalbinet.github.io',
                'git_url': 'https://github.com/franckalbinet/evaluatr',
                'lib_path': 'evaluatr'},
  'syms': {'evaluatr.core': {'evaluatr.core.foo': ('core.html#foo', 'evaluatr/core.py')}}}
